def main():
	print('''
	AON (Advanced object notation)
	------------------------------

	Description:
	-----------
		*This is similar to JSON but it was developed using python.
		*Python is having huge community and opensource so this is a base version.
	Usage:
	-----
		*It has two method make inside maker package which will convert your AON file by taking path as arg.
		*load method return the data from the AON file.
		Note: without calling make method no data available.
	Contact Details:
	---------------
	Koppula Praveen Kumar
	koppulapraveen920@gmail.com
	 ''')
